@@ -516,8 +516,6 @@ gjs_context_constructed(GObject *object)
     g_mutex_unlock (&contexts_lock);
 
     setup_dump_heap();
-
-    g_object_weak_ref(object, gjs_object_context_dispose_notify, nullptr);
 }
 
 static void
@@ -616,10 +614,9 @@ _gjs_context_schedule_gc_internal(GjsContext *js_context,
     if (js_context->auto_gc_id > 0)
         return;
 
-    js_context->force_gc |= force_gc;
-    js_context->auto_gc_id = g_timeout_add_seconds_full(G_PRIORITY_LOW, 10,
-                                                        trigger_gc_if_needed,
-                                                        js_context, NULL);
+    js_context->auto_gc_id = g_idle_add_full(G_PRIORITY_LOW,
+                                             trigger_gc_if_needed,
+                                             js_context, NULL);
 }
 
 void
