@@ -26,8 +26,6 @@
 
 #include <codecvt>
 #include <locale>
-#include "jsapi-wrapper.h"
-#include <js/GCAPI.h>
 
 #include <util/log.h>
 #include <util/glib.h>
@@ -36,6 +34,7 @@
 
 #include "jsapi-class.h"
 #include "jsapi-util.h"
+#include "jsapi-wrapper.h"
 #include "context-private.h"
 #include <gi/boxed.h>
 
@@ -733,7 +732,7 @@ gjs_gc_if_needed (JSContext *context)
          */
         if (rss_size > linux_rss_trigger) {
             linux_rss_trigger = (gulong) MIN(G_MAXULONG, rss_size * 1.25);
-            JS::GCForReason(context, GC_SHRINK, JS::gcreason::Reason::API);
+            JS_GC(context);
         } else if (rss_size < (0.75 * linux_rss_trigger)) {
             /* If we've shrunk by 75%, lower the trigger */
             linux_rss_trigger = (rss_size * 1.25);
